MODULE usrdef_istate
   !!======================================================================
   !!                   ***  MODULE  usrdef_istate   ***
   !!
   !!                   ===  COMODO-IW configuration  ===
   !!
   !! User defined : set the initial state of a user configuration
   !!======================================================================
   !! History :  4.0 ! 2018-09 (J. Chanut) Original code
   !!----------------------------------------------------------------------

   !!----------------------------------------------------------------------
   !!  usr_def_istate : initial state in Temperature and salinity
   !!----------------------------------------------------------------------
   USE par_oce        ! ocean space and time domain
   USE phycst         ! physical constants
   USE eosbn2, ONLY : rn_a0
   !
   USE in_out_manager ! I/O manager
   USE lib_mpp        ! MPP library
   
   IMPLICIT NONE
   PRIVATE

   PUBLIC   usr_def_istate   ! called in istate.F90

   !!----------------------------------------------------------------------
   !! NEMO/OCE 4.0 , NEMO Consortium (2018)
   !! $Id:$ 
   !! Software governed by the CeCILL licence     (./LICENSE)
   !!----------------------------------------------------------------------
CONTAINS
  
   SUBROUTINE usr_def_istate( pdept, ptmask, pts, pu, pv, pssh )
      !!----------------------------------------------------------------------
      !!                   ***  ROUTINE usr_def_istate  ***
      !! 
      !! ** Purpose :   Initialization of the dynamics and tracers
      !!                for "COMODO internal waves" setup
      !!
      !! ** Method  : - set temprature field
      !!              - set salinity   field
      !!----------------------------------------------------------------------
      REAL(wp), DIMENSION(jpi,jpj,jpk)     , INTENT(in   ) ::   pdept   ! depth of t-point               [m]
      REAL(wp), DIMENSION(jpi,jpj,jpk)     , INTENT(in   ) ::   ptmask  ! t-point ocean mask             [m]
      REAL(wp), DIMENSION(jpi,jpj,jpk,jpts), INTENT(  out) ::   pts     ! T & S fields      [Celsius ; g/kg]
      REAL(wp), DIMENSION(jpi,jpj,jpk)     , INTENT(  out) ::   pu      ! i-component of the velocity  [m/s] 
      REAL(wp), DIMENSION(jpi,jpj,jpk)     , INTENT(  out) ::   pv      ! j-component of the velocity  [m/s] 
      REAL(wp), DIMENSION(jpi,jpj)         , INTENT(  out) ::   pssh    ! sea-surface height
      !
      INTEGER :: ji, jj, jk  ! dummy loop indices
      INTEGER :: kcase
      REAL(wp):: znn         ! Stratification
      !!----------------------------------------------------------------------
      !
      IF(lwp) WRITE(numout,*)
      IF(lwp) WRITE(numout,*) 'usr_def_istate : analytical definition of initial state '
      IF(lwp) WRITE(numout,*) '~~~~~~~~~~~~~~   Ocean at rest, with an horizontally uniform T and S profiles'
      !
      pu  (:,:,:) = 0._wp        ! ocean at rest
      pv  (:,:,:) = 0._wp
      pssh(:,:)   = 0._wp
      !
      znn = 0.002_wp ! N [s-1]
      kcase = 1 
      !
      SELECT CASE ( kcase )
         !
      CASE( 1 )
         DO jk = 1, jpk             ! Linearly stratified
            DO jj = 1, jpj
               DO ji = 1, jpi
                  pts(ji,jj,jk,jp_tem) = (10._wp - (1026.2_wp-rau0) / rn_a0 &
                       &                -(znn**2) * rau0 /grav / rn_a0 &
                       &               * (pdept(ji,jj,jk)-50._wp)           &
                       &                 ) * ptmask(ji,jj,jk)
                  pts(ji,jj,jk,jp_sal) = 35._wp * ptmask(ji,jj,jk)
               END DO
            END DO
         END DO
      !
      CASE( 2 )
         DO jk=1, jpkm1             ! Interfacial waves:
            DO jj=1,jpj             ! Set a two layer system with
               DO ji=1,jpi          ! a density jump = 1.2 kg/m3 at z=50m
                  IF ( 0.5_wp*(pdept(ji,jj,jk)+pdept(ji,jj,jk+1))<= 50._wp ) THEN
                     pts(ji,jj,jk,jp_tem) = (10._wp - (1025.8_wp-rau0) / rn_a0 ) * ptmask(ji,jj,jk)
                  ELSE                        
                     pts(ji,jj,jk,jp_tem) = (10._wp - (1027.0_wp-rau0) / rn_a0 ) * ptmask(ji,jj,jk)
                  ENDIF
                  pts(ji,jj,jk,jp_sal) = 35._wp * ptmask(ji,jj,jk)
               END DO
            END DO
         END DO
         !
      CASE( 3 )
         DO jk=1, jpkm1             ! Interfacial waves:
            DO jj=1,jpj                       ! stratification + mixed layer and thermocline
               DO ji=1,jpi
                  IF (pdept(ji,jj,jk)< 50._wp) THEN
                     pts(ji,jj,jk,jp_tem) = (10._wp - (1025.0_wp-rau0) / rn_a0 ) * ptmask(ji,jj,jk)
                  ELSEIF ((pdept(ji,jj,jk)>= 50._wp).AND.(pdept(ji,jj,jk)< 60._wp)) THEN
                     pts(ji,jj,jk,jp_tem) =  (10._wp - (1026.2_wp-rau0) / rn_a0                   & 
                     &                       -(znn**2) * rau0 /grav / rn_a0                  & 
                     &                        * (pdept(ji,jj,jk)-50._wp)                          &
                     &                       -1.2_wp * (pdept(ji,jj,jk)-60._wp) / 10._wp / rn_a0  &
                     &                      ) * ptmask(ji,jj,jk)
                  ELSEIF  (pdept(ji,jj,jk)>= 60._wp) THEN
                     pts(ji,jj,jk,jp_tem) = (10._wp - (1026.2_wp-rau0) / rn_a0    & 
                     &                       -(znn**2) * rau0 /grav / rn_a0  & 
                     &                        * (pdept(ji,jj,jk)-50._wp)          &
                     &                      ) * ptmask(ji,jj,jk)
                  ENDIF
                  pts(ji,jj,jk,jp_sal) = 35._wp * ptmask(ji,jj,jk)
               END DO
            END DO
         END DO
      !
      END SELECT
      !   
   END SUBROUTINE usr_def_istate

   !!======================================================================
END MODULE usrdef_istate
